#[non_exhaustive]pub enum CVarError {
UnknownCVar,
BadCVarType,
MissingCid,
CannotDeserialize,
FailedDeserialize(String),
FailedApply {
inner: ApplyError,
},
AccessConflict,
TomlError(TomlError),
MalformedConfigDuringWrite(&'static str),
TomlSerError(Error),
}Expand description
Errors that can occur when manipulating CVars.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
UnknownCVar
Error indicating a CVar was never registered or is invalid.
BadCVarType
Error indicating the given CVar type is invalid.
MissingCid
Error indicating the CVar type is missing a ComponentId and is likely not registered correctly.
CannotDeserialize
Error indicating the underlying type of the CVar cannot be deserialized, and as such cannot be reflected over.
FailedDeserialize(String)
Error indicating the CVar failed to deserialize.
FailedApply
Error indicating applying a value to the CVar failed, containing the inner error.
Fields
inner: ApplyErrorThe inner error.
AccessConflict
Error indicating that the world could not fulfill the requested operation due to an access conflict with an ongoing operation.
TomlError(TomlError)
An error when parsing a TOML document.
MalformedConfigDuringWrite(&'static str)
An error when saving encounters malformed TOML structure.
TomlSerError(Error)
An error when serializing TOML data.