pub struct CVarLoaderPlugin { /* private fields */ }Expand description
Plugin that provides layered config loading for CVars, and additionally manages the user config file.
During build, the plugin will load any layers it was configured to load, and also any asset layers named by ConfigLayers
Remarks
This plugin MUST be added after all other CVar registering plugins. It’s recommended to seperate CVar registration from other plugin registration to ensure it’s done first.