pub struct CVarLoaderPluginBuilder { /* private fields */ }Expand description
A builder to create a new CVarLoaderPlugin
Implementations
Sourceimpl CVarLoaderPluginBuilder
impl CVarLoaderPluginBuilder
Sourcepub fn fancy() -> Self
pub fn fancy() -> Self
The fancy default, loading layers from the asset path ConfigLayers/ and automatically loading the default layers.
Does not set the user config file path or add any extra layers.
Sourcepub fn load_default_layers(self) -> Self
pub fn load_default_layers(self) -> Self
Adds the default layers to the load list. The following layers are ‘default’ and may be added depending on build configuration:
debug_assertions.tomlforcfg(debug_assertions)
Sourcepub fn add_asset_layer_if(self, given: bool, layer: &'static str) -> Self
pub fn add_asset_layer_if(self, given: bool, layer: &'static str) -> Self
Conditionally adds an asset layer, meant to be used with cfg! or other conditions.
You should prefer actual rust if statements for anything complex.
let builder =
CVarLoaderPluginBuilder::fancy()
.add_asset_layer_if(cfg!(feature = "dev_tools"), "dev_tools.toml")
.add_asset_layer_if(cfg!(feature = "release"), "release.toml");
Sourcepub fn add_asset_layer(self, layer: &'static str) -> Self
pub fn add_asset_layer(self, layer: &'static str) -> Self
Adds an asset layer to the builder.
Sourcepub fn with_layers_root(self, path: AssetPath<'static>) -> Self
pub fn with_layers_root(self, path: AssetPath<'static>) -> Self
Sets the root for config layers.
Sourcepub fn with_user_config_file(self, path: PathBuf) -> Self
pub fn with_user_config_file(self, path: PathBuf) -> Self
Sets the user config file location.
Sourcepub fn with_asset_layer(self, path: PathBuf) -> Self
pub fn with_asset_layer(self, path: PathBuf) -> Self
Adds a layer to load from the layer root. This should be a file relative to the root.
Sourcepub fn add_layer(self, layer: DocumentContext<String>) -> Self
pub fn add_layer(self, layer: DocumentContext<String>) -> Self
Adds a pre-parsed config layer to apply.
Sourcepub fn build(self) -> CVarLoaderPlugin
pub fn build(self) -> CVarLoaderPlugin
Consumes the builder to create a CVarLoaderPlugin.