#[non_exhaustive]pub enum CVarOverrideParseError {
InvalidPath,
InvalidToml,
DoesntLookLikeAnOverride,
}Expand description
Errors that can occur parsing a CVarOverride
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPath
Error indicating the override is invalid as the left side is not a path.
InvalidToml
Error indicating the override is invalid as the right side is not valid TOML.
DoesntLookLikeAnOverride
Error indicating the override is invalid as it doesn’t even look like an override (left=right)