pub struct CVarSaveContext(/* private fields */);Expand description
Provides a context for mutating a TOML document to save CVars to it.
Example
let mut context = CVarSaveContext::blank();
// Let's save the world config to this.
context.save_world(&world);
// And serialize out the results so we can save it.
let file_contents = context.to_string();Implementations
Sourceimpl CVarSaveContext
impl CVarSaveContext
Sourcepub fn from_document(doc: DocumentMut) -> Self
pub fn from_document(doc: DocumentMut) -> Self
Creates a new context with an existing document.
Sourcepub fn return_document(self) -> DocumentMut
pub fn return_document(self) -> DocumentMut
Returns the document used from the context, destroying the context.
Sourcepub fn save_cvar<T: CVarMeta>(&mut self, cvar: &T) -> Result<(), CVarError>
pub fn save_cvar<T: CVarMeta>(&mut self, cvar: &T) -> Result<(), CVarError>
Manually save an individual CVar to the document.
Remarks
This does not check for the presence of CVarFlags::SAVED, and as such can be used to specially handle some CVars.
Sourcepub fn save_cvar_from_world<T: CVarMeta>(
&mut self,
world: &World,
) -> Result<(), CVarError>
pub fn save_cvar_from_world<T: CVarMeta>( &mut self, world: &World, ) -> Result<(), CVarError>
Manually save an individual CVar to the document, from the world.
Remarks
This does not check for the presence of CVarFlags::SAVED, and as such can be used to specially handle some CVars.
Sourcepub fn save_world(&mut self, world: &World) -> Result<(), CVarError>
pub fn save_world(&mut self, world: &World) -> Result<(), CVarError>
Saves a world’s CVars to the document.
Remarks
This obeys CVarFlags::SAVED and will not attempt to save CVars without it.