CVarManagement

Struct CVarManagement 

pub struct CVarManagement { /* private fields */ }
App resource that provides management information and functionality for CVars.

Implementations

Source

impl CVarManagement

pub fn get_cvar_reflect<'a>( &self, world: &'a World, cvar: &str, ) -> Result<&'a dyn Reflect, CVarError>

Gets a CVar’s value through reflection.

Remarks

This returns the inner value, not the cvar resource itself.

pub fn get_cvar_reflect_mut<'a>( &self, world: &'a mut World, cvar: &str, ) -> Result<Mut<'a, dyn Reflect>, CVarError>

Gets a CVar’s value mutably through reflection.

Remarks

This returns the inner value, not the cvar resource itself. A change-detection aware handle is returned.

pub fn set_cvar_reflect( &self, world: &mut World, cvar: &str, value: &dyn Reflect, ) -> Result<(), CVarError>

Set a CVar to the given reflected value using reflection.

Remarks

Use the WorldExtensions version if you can, it handles the invariants. This is harder to call than it looks due to needing mutable world.

pub fn set_cvar_reflect_no_change( &self, world: &mut World, cvar: &str, value: &dyn Reflect, ) -> Result<(), CVarError>

Set a CVar to the given reflected value using reflection, without triggering change detection.

Remarks

Use the WorldExtensions version if you can, it handles the invariants. This is harder to call than it looks due to needing mutable world.

pub fn set_cvar_deserialize<'w, 'a>( &self, world: &mut World, cvar: &str, value: impl Deserializer<'a>, ) -> Result<(), CVarError>

Set a CVar to the given deserializable value using reflection.

Remarks

Use the WorldExtensions version if you can, it handles the invariants. This is harder to call than it looks due to needing mutable world.

pub fn set_cvar_deserialize_no_change<'w, 'a>( &self, world: &mut World, cvar: &str, value: impl Deserializer<'a>, ) -> Result<(), CVarError>

Set a CVar to the given deserializable value using reflection, without triggering change detection.

Remarks

Use the WorldExtensions version if you can, it handles the invariants. This is harder to call than it looks due to needing mutable world.

pub fn iterate_cvar_types(&self) -> impl Iterator<Item = &TypeRegistration>

Returns an iterator for all CVar type registrations.